@@ -9,9 +9,9 @@ import os
 from pathlib import Path, PurePosixPath
 from typing import Iterable
 
-from ..dataset import Data, Segment
-from .tbrn import TBRN, TBRNType
-from .utility import ContextInfo, error, exception_handler, get_dataset_client
+from tensorbay.cli.tbrn import TBRN, TBRNType
+from tensorbay.cli.utility import ContextInfo, error, exception_handler, get_dataset_client
+from tensorbay.dataset import Data, Segment
 
 
 @exception_handler
@@ -46,7 +46,9 @@ def _implement_cp(  # pylint: disable=too-many-arguments
         segment = _get_segment(
             tbrn_info.segment_name, local_abspaths, target_remote_path, is_recursive
         )
-        dataset_client.upload_segment(segment, jobs=jobs, skip_uploaded_files=skip_uploaded_files)
+        dataset_client.upload_segment(
+            segment, jobs=jobs, skip_uploaded_files=skip_uploaded_files, _is_cli=True
+        )
 
 
 def _get_segment(
