@@ -3,25 +3,9 @@
 # Copyright 2021 Graviti. Licensed under MIT License.
 #
 
-"""Class DatasetClientBase, DatasetClient and FusionDatasetClient.
-
-:class:`DatasetClient` is a remote concept. It contains the information
-needed for determining a unique dataset on TensorBay, and provides a series of methods within
-dataset scope, such as :meth:`DatasetClient.get_segment`, :meth:`DatasetClient.list_segment_names`,
-:meth:`DatasetClient.commit <DatasetClientBase.commit>`, and so on.
-In contrast to the :class:`DatasetClient`,
-:class:`~tensorbay.dataset.dataset.Dataset` is a local concept. It represents a
-dataset created locally. Please refer to
-:class:`~tensorbay.dataset.dataset.Dataset` for more information.
-
-Similar to the :class:`DatasetClient`, the
-:class:`FusionDatasetClient` represents
-the fusion dataset on TensorBay, and its local counterpart is
-:class:`~tensorbay.dataset.dataset.FusionDataset`.
-Please refer to :class:`~tensorbay.dataset.dataset.FusionDataset` for more information.
-
-"""
+"""The remote dataset on TensorBay."""
 
+import functools
 import logging
 import os
 import shutil
@@ -41,7 +25,7 @@ from tensorbay.client.requests import multithread_upload
 from tensorbay.client.segment import _STRATEGIES, FusionSegmentClient, SegmentClient
 from tensorbay.client.statistics import Statistics
 from tensorbay.client.status import Status
-from tensorbay.client.version import VersionControlMixin
+from tensorbay.client.version import SquashAndMerge, VersionControlMixin
 from tensorbay.dataset import AuthData, Data, Frame, FusionSegment, Notes, RemoteData, Segment
 from tensorbay.exception import (
     FrameError,
@@ -233,6 +217,17 @@ class DatasetClientBase(VersionControlMixin):
         """
         return bool(self._cache_path) and not self.status.is_draft
 
+    @property  # type: ignore[misc]
+    @functools.lru_cache()
+    def squash_and_merge(self) -> SquashAndMerge:
+        """Get class :class:`~tensorbay.client.version.SquashAndMerge`.
+
+        Returns:
+            Required :class:`~tensorbay.client.version.SquashAndMerge`.
+
+        """
+        return SquashAndMerge(self._client, self._dataset_id, self._status, self.get_draft)
+
     def enable_cache(self, cache_path: str = "") -> None:
         """Enable cache when open the remote data of the dataset.
 
