@@ -17,6 +17,7 @@ from tensorbay.opendataset.CADC import CADC
 from tensorbay.opendataset.CarConnection import CarConnection
 from tensorbay.opendataset.CCPD import CCPD, CCPDGreen
 from tensorbay.opendataset.CIHP import CIHP
+from tensorbay.opendataset.Cityscapes import CityscapesGTCoarse, CityscapesGTFine
 from tensorbay.opendataset.COCO2017 import COCO2017
 from tensorbay.opendataset.CoinImage import CoinImage
 from tensorbay.opendataset.CompCars import CompCars
@@ -48,6 +49,8 @@ from tensorbay.opendataset.nuImages import nuImages
 from tensorbay.opendataset.nuScenes import nuScenes
 from tensorbay.opendataset.OxfordIIITPet import OxfordIIITPet
 from tensorbay.opendataset.PASCALContext import PASCALContext
+from tensorbay.opendataset.RarePlanesReal import RarePlanesReal
+from tensorbay.opendataset.RarePlanesSynthetic import RarePlanesSynthetic
 from tensorbay.opendataset.RP2K import RP2K
 from tensorbay.opendataset.SCUT_FBP5500 import SCUT_FBP5500
 from tensorbay.opendataset.SegTrack import SegTrack
@@ -57,6 +60,8 @@ from tensorbay.opendataset.THCHS30 import THCHS30
 from tensorbay.opendataset.THUCNews import THUCNews
 from tensorbay.opendataset.TLR import TLR
 from tensorbay.opendataset.UAVDT import UAVDT
+from tensorbay.opendataset.UrbanObjectDetection import UrbanObjectDetection
+from tensorbay.opendataset.VGGFace2 import VGGFace2
 from tensorbay.opendataset.VOC2012ActionClassification import VOC2012ActionClassification
 from tensorbay.opendataset.VOC2012Detection import VOC2012Detection
 from tensorbay.opendataset.VOC2012Segmentation import VOC2012Segmentation
@@ -80,6 +85,8 @@ __all__ = [
     "CCPD",
     "CCPDGreen",
     "CIHP",
+    "CityscapesGTCoarse",
+    "CityscapesGTFine",
     "COCO2017",
     "CoinImage",
     "COVIDChestXRay",
@@ -112,6 +119,8 @@ __all__ = [
     "NightOwls",
     "OxfordIIITPet",
     "PASCALContext",
+    "RarePlanesReal",
+    "RarePlanesSynthetic",
     "RP2K",
     "SCUT_FBP5500",
     "SegTrack",
@@ -122,8 +131,10 @@ __all__ = [
     "THUCNews",
     "TLR",
     "UAVDT",
+    "UrbanObjectDetection",
     "WIDER_FACE",
     "COVID_CT",
+    "VGGFace2",
     "VOC2012Detection",
     "VOC2012ActionClassification",
     "VOC2012Segmentation",
