@@ -7,5 +7,6 @@
 
 from tensorbay.opendataset._utility.coco import coco
 from tensorbay.opendataset._utility.glob import glob
+from tensorbay.opendataset._utility.voc import get_boolean_attributes, get_voc_detection_data
 
-__all__ = ["coco", "glob"]
+__all__ = ["coco", "glob", "get_voc_detection_data", "get_boolean_attributes"]
