@@ -17,7 +17,7 @@ from tensorbay.utility.file import URL, FileMixin, RemoteFileMixin
 from tensorbay.utility.itertools import chunked
 from tensorbay.utility.name import NameList, NameMixin, SortedNameList
 from tensorbay.utility.repr import ReprMixin, ReprType, repr_config
-from tensorbay.utility.request_config import config
+from tensorbay.utility.requests import Tqdm, UserResponse, UserSession, config, get_session
 from tensorbay.utility.type import TypeEnum, TypeMixin, TypeRegister
 from tensorbay.utility.user import (
     UserMapping,
@@ -41,6 +41,7 @@ __all__ = [
     "ReprMixin",
     "ReprType",
     "SortedNameList",
+    "Tqdm",
     "TypeEnum",
     "TypeMixin",
     "TypeRegister",
@@ -48,7 +49,9 @@ __all__ = [
     "UserMapping",
     "UserMutableMapping",
     "UserMutableSequence",
+    "UserResponse",
     "UserSequence",
+    "UserSession",
     "attr",
     "attr_base",
     "camel",
@@ -57,5 +60,6 @@ __all__ = [
     "config",
     "locked",
     "repr_config",
+    "get_session",
     "upper",
 ]
